@@ -2,7 +2,7 @@ package Pixie::Name;
 
 use strict;
 
-our $VERSION = '2.04';
+our $VERSION='2.05';
 
 sub new {
   my $proto = shift;
@@ -18,9 +18,17 @@ sub name_object_in {
 
 sub get_object_from {
   my $proto = shift;
-  my($name, $pixie) = @_;
-  my $name_obj  = $pixie->get("<NAME:$name>");
-  return unless $name_obj;
+  my($name, $pixie, $strategy) = @_;
+  $proto->do_restoration( defined($strategy) ?
+			  $pixie
+			    ->get_with_strategy("<NAME:$name>", $strategy) :
+			  $pixie->get("<NAME:$name>"));
+}
+
+sub do_restoration {
+  my $self = shift;
+
+  return unless my $name_obj = shift;
   my $target = $name_obj->px_target;
   if (wantarray) {
     return map { eval { $_->px_restore } || $_ } @$target;
@@ -32,6 +40,12 @@ sub get_object_from {
   }
 }
 
+sub get_object_from_with_strategy {
+  my $proto = shift;
+  my($name, $pixie, $strategy) = @_;
+  $proto->do_restoration($pixie->get_with_strategy("<NAME:$name>"));
+}
+
 sub remove_name_from {
   my $proto = shift;
   my($name, $pixie) = @_;
