@@ -1,6 +1,6 @@
 package Pixie::Store::Memory;
 
-our $VERSION = '2.04';
+our $VERSION='2.05';
 
 use Storable qw/nfreeze thaw/;
 
@@ -14,7 +14,10 @@ sub new {
 }
 
 sub init {
-  return $_[0];
+  my $self = shift;
+  $self->{store} = {};
+  $self->{rootset} = {};
+  return $self;
 }
 
 
@@ -23,11 +26,37 @@ sub connect {
   $self = ref($self) ? $self : $self->new;
 }
 
-sub delete {
+sub remove_from_rootset {
+  my $self = shift;
+  my $oid = shift;
+  delete $self->{rootset}{$oid};
+  return $self;
+}
+
+
+sub _add_to_rootset {
+  my $self = shift;
+  my $thing = shift;
+  $self->{rootset}{$thing->PIXIE::oid} = 1;
+  return $self;
+}
+
+sub rootset {
+  my $self = shift;
+  keys %{$self->{rootset}};
+}
+
+
+sub working_set_for {
+  my $self = shift;
+  my @ret = keys %{$self->{store}};
+  return wantarray ? @ret : \@ret;
+}
+
+sub _delete {
   my $self = shift;
   my($oid) = @_;
-
-  defined(delete($$self{$oid})) ? 1 : 0;
+  defined(delete $self->{store}{$oid}) ? 1 : 0;
 }
 
 sub store_at {
@@ -35,7 +64,7 @@ sub store_at {
   my($oid, $obj) = @_;
 
   if ($oid) {
-    $self->{$oid} = nfreeze($obj);
+    $self->{store}{$oid} = nfreeze($obj);
     return($oid, $obj);
   }
   else {
@@ -47,7 +76,7 @@ sub get_object_at {
   my $self = shift;
   my($oid) = @_;
 
-  return thaw $self->{$oid};
+  return thaw $self->{store}{$oid};
 }
 
 sub lock { }
@@ -56,7 +85,9 @@ sub rollback { }
 
 sub clear {
   my $self = shift;
-  %$self = ();
+
+  %{$self->{store}} = ();
+  %{$self->{rootset}} = ();
   return $self;
 }
 
@@ -65,10 +96,10 @@ sub delete_object_at {
   my($oid) = @_;
 
   if (defined(wantarray)) {
-    return thaw delete $self->{$oid};
+    return thaw delete $self->{store}{$oid};
   }
   else {
-    delete $self->{$oid};
+    delete $self->{store}{$oid};
   }
 }
 
